==> muid-0.2.2.tar.gz: muid-0.2.2/muid/explanation.py <==


EXPLANATION = ["This script runs a simple open source mining routine from the MUID package, available at https://pypi.org/project/muid/",
            "If at any point you feel uncomfortable just Control-C",
            "                   ",
            "The script searches for hash-memorable keys",
            "This takes a while so the script is a little chatty, sorry.",
            "You should hear your laptop fan pretty soon.",
            " ",
            "A hash-memorable key is a unique identifier - which is to say a long randomly generated string representing a hexidecimal number",
            "Such as 683697d0c930403aa0c700f6c29596c4",
            "We thought about calling them malarkeys",
            "But that wouldn't be overly descriptive",
            " ",
            "A hash-memorable key, or hash-memorable unique identifier (MUID for short) has another property which makes them hard to find",
            "To explain, we use a hash function that takes one hex number and turns it into another",
            "For example, 43c0d40ec2eb68e02c8beb2fe62f1e6c -> 5e8edb00b4bab85786350f354bd67c8b ",
            " ",
            "Aside: a hash is a just a function that is almost impossible to invert. See https://en.wikipedia.org/wiki/Hash_function",
            "We use the SHA-256 algorithm, which is completely standard and also used in bitcoin mining",
            " ",
            "This script does nothing but generate a vast number of random hexadecimal numbers in the hope that the hash function, when applied to them, accidentally produces a recognizable string",
            "Actually the strings aren't that recognizable unless you squint, and replace digits with letters (like 0->o, 7->t and so forth)",
            "We've introduced the notion of readable hex, in this manner.",
            "The rules for coverting digits to letters are at https://pypi.org/project/muid/",
            "And to save your eyesight we'll print the translation of the leading part of the hashed key.",
            "  ",
            "Back to our example  43c0d40ec2eb68e02c8beb2fe62f1e6c -> 5e8edb00b4bab85786350f354bd67c8b ",
            "Most of the time the second string will be gibberish, just like the first.",
            "But sometimes ...",
            "...if you are lucky ...",
            "...the second string will try to tell you something about yourself.",
            "It will reveal your spirit animal.",
            " ",
            "Don't believe me?",
            "Look a little closer at the first ten characters of 5e8edb00b4bab85786350f354bd67c8b",
            "Namely, 5e8ed b00b4",
            " ",
            "In readable hex they read ... ",
            "Sexed Booby",
            " ",
            "Aside: A Booby is a seabird in the genus Sula, part of the Sulidae family. Boobies are closely related to the gannets (Morus), which were formerly included in Sula. [source:Google] ",
            "It is important that they thrive.",
            " ",
            "But you will have plenty of choices if you don't like that one. We've found a bunch already while simultaneously heating your home.",
            " ",
            "Hash-memorable keys can be used to create applications with one less join.",
            "The key is intended to be private, but the hash can be public including the spirit animal",
            "For example the spirit animal becomes your nom de plume should you wish to participate in at www.microprediction.com",
            "   ",
            "More on that in a minute",
            "    ",
            "But first, if you do manage to generate an amusing spirit animal, by all means share it at https://www.quora.com/unanswered/What-are-the-most-amusing-hash-memorable-identifiers-you-have-generated ",
            "Or vote there"
            "  ",
            "  " 
            "The most important thing about your spirit animal, let's say 'Foldable Cat' for example, is the sum of the lengths of the two words",
            "In this case the sum is 11 and this is called the length",
            "Very imaginative terminology, no?",
            "Well the length, sometimes called the difficulty is important.",
            "Maybe not as important as your liking your  'Colossal Oca', but the length determines its utilitarian value.",
            "     ",
            "Which brings us to the motivation for running this script",
            "    ",
            "Why would you want hash-memorable keys?",
            "    ",
            "Good question",
            "      ",
            "Bit of a long answer",
            "  ",
            "The short version is this: there's a microprediction web coming",
            "The microprediction web will, asymptotically, make bespoke AI cheap and ubiquitous ... though it will have humble beginnings",
            "A microprediction web will make consulting companies, artisan data scientists, and overpaid pompous managers about as relevant to model and data search as the librarian who didn't help you find this script.",
            " ",
            "We like librarians ... but there is a message in the plot here:  https://blog.oup.com/2011/06/librarian-census/    ",
            "And more importantly there is a rather obvious contradiction at the heart of the so-called AI revolution",
            " ",
            "The contradiction runs as follows:",
            "   ",
            "   (A) The Machine Learning revolution is 'just' a bunch of problems where there is sufficient data to distinguish good from bad models by means of a simple score",
            "       Of course it is also a bunch of very clever work ... not downplaying that at all ... ",
            "          ... but ... ",
            " ",
            "   (B) It also comprises a flood with mind-numbingly stupid powerpoint slides written by recent applied statisticians. ",
            "       Who claim that their human ability to manage the production of prediction is essential",
            "       Even though it mostly amounts to stating the obvious",
            "  ",
            "We say: what a load of malarkey. If there is enough data to distinguish good models from bad, the machines should be managing the humans and not the other way around.",
            " At least for a class of problems so defined, which we term 'microprediction' ",
            " Which is not to be confused with predicting singular events like the outcome of the 2020 US election. ",
            " ",
            "Anyway, thankfully this script is helping in some small way",
            "By running it you are not just sitting on your hands ",
            "You are helping to stop the proliferation of expensive cold-start data science.",
            "You are taking a stand against the quaint aspirations of so-called 'number scientists'.",
            "You are helping in some small way mage progress towards affordable bespoke AI for small to medium size enterprises.",
            "You are helping in some small way to address a tragedy of the commons: the lack of a common realtime feature space.",
            "Which would have been really useful when Corono took off now, it must be admitted.",
            "That's all because hash-memorable keys carry special significance at www.microprediction.com, humble birthplace of the predictino web.",
            "The keys serve as an entry ticket, one you - or someone you kindsly donate your key to - can use in two ways.",
            "    ",
            "   (1) They enable you to enter realtime statistical prediction contests. The more difficult your key, the greater drawdown leeway you will be granted.",
            "       That's a nice way of saying that you are less likely to be kicked out because your key is declared bankrupt",
            "     ",
            "   (2) Keys enable you to ask other people and algorithms to predict live data that you care about",
            "       That can be anything at all.",
            "       But more difficult the key you supply, the more accurate the predictions will be.",
            "       That's because self-navigating automated prediction algorithms, and human guided models, are more likely to find their way to your data stream and"
            "       when they get there, will have have more incentive to fight.",
            "      ",
            "Now as a small technical matter, www.microprediction.com isn't quite operational yet.",
            "But it is close ... probably April 1, 2020 ... but don't hold me to it",
            "So we are allowing you to run this script now because it can take weeks to mine a really valuable key.",
            "And no doubt you are an under-appreciated mathematical genius ... ",
            "... or your know one who would love a really difficult key",
            " ",
            "By the way, you can run this in multiple terminals at the same time. It should only chew up 50 MB each time.",
            "We thought it would be rude to take all your processors without asking",
            "   ",
            "Oh wait I know what you are thinking ...",
            "What if I don't care about microprediction or statistics or AI or whatever and I just want to mine",
            "Will this be more economical than mining bitcoin?",
            "    ",
            "A moment's reflection might convince you that is the case, assuming ",
            "... the monetary rewards at www.microprediction.com are going to be serious",
            "... because at least one top tier investment company intends to use microprediction.com for a variety of purposes",
            "... and it is likely to be useful for many businesses",
            " ",
            "Indeed it seems plausible that some participants may be impatient",
            "... and less prescient than yourself",
            "... and thus your longer keys may be valuable to them",
            "... but we can't make any promises",
            "... though we might in the near future provide an API where you can sell keys you don't want",
            "... maybe.  ",
            " ",
            "Anyway, thanks for listenning.",
            "Next time run python3 -c 'from muid import mine; mine(skip_intro=True)' to avoid this rant and the install",
            "Here come your keys and corresponding spirit animals. ",
            "   ",
           ]

==> muid-0.2.3.tar.gz: muid-0.2.3/muid/explanation.py <==

TITLE = """                         
         __    __     __    __    _____   ______              
         \ \  / /     ) )  ( (   (_   _) (_  __ \             
         () \/ ()    ( (    ) )    | |     ) ) \ \            
         / _  _ \     ) )  ( (     | |    ( (   ) )           
        / / \/ \ \   ( (    ) )    | |     ) )  ) )           
       /_/      \_\   ) \__/ (    _| |__  / /__/ /            
      (/          \)  \______/   /_____( (______/             
                                
             Memorable Unique Identifiers                                                
   __    __      _____      __      _    _____   ______       
   \ \  / /     (_   _)    /  \    / )  / ___/  (   __ \      
   () \/ ()       | |     / /\ \  / /  ( (__     ) (__) )     
   / _  _ \       | |     ) ) ) ) ) )   ) __)   (    __/      
  / / \/ \ \      | |    ( ( ( ( ( (   ( (       ) \ \  _     
 /_/      \_\    _| |__  / /  \ \/ /    \ \___  ( ( \ \_))    
(/          \)  /_____( (_/    \__/      \____\  )_) \__/                                             
                                              
           https://pypi.org/project/muid/
           
                 Mining has begun  
"""

EXPLANATION = ["This script runs a simple open source mining routine from the MUID package",
            "Code is available at https://github.com/microprediction/muid to read",
             "You should hear your laptop fan firing up.",
            "If at any point you feel uncomfortable, or your computer does, just Control-C",
            "                   ",
            "The script searches for hash-memorable keys",
            "This takes a while so the script is a little chatty, sorry.",
            " ",
            "A hash-memorable key is a unique identifier - which is to say a long randomly generated string representing a hexidecimal number",
            "Such as 683697d0c930403aa0c700f6c29596c4",
            " ",
            "A hash-memorable key, or hash-memorable unique identifier (MUID for short) has another property which makes them hard to find",
            "To explain, we use a hash function that takes one hex number and turns it into another",
            "For example, 43c0d40ec2eb68e02c8beb2fe62f1e6c -> 5e8edb00b4bab85786350f354bd67c8b ",
            " ",
            "Aside: a hash is a just a function that is almost impossible to invert. See https://en.wikipedia.org/wiki/Hash_function",
            "We use the SHA-256 algorithm, which is completely standard and also used in bitcoin mining",
            " ",
            "This script does nothing but generate a vast number of random hexadecimal numbers in the hope that the hash function, when applied to them, accidentally produces a recognizable string",
            "Actually the strings aren't that recognizable unless you squint, and replace digits with letters (like 0->o, 7->t and so forth)",
            "We've introduced the notion of readable hex, in this manner.",
            "The rules for coverting digits to letters are at https://pypi.org/project/muid/",
            "And to save your eyesight we'll print the translation of the leading part of the hashed key.",
            "  ",
            "Back to our example  43c0d40ec2eb68e02c8beb2fe62f1e6c -> 5e8edb00b4bab85786350f354bd67c8b ",
            "Most of the time the second string will be gibberish, just like the first.",
            "But sometimes ...",
            "...if you are lucky ...",
            "...the second string will try to tell you something about yourself.",
            "It will reveal your spirit animal.",
            " ",
            "Don't believe me?",
            "Look a little closer at the first ten characters of 5e8edb00b4bab85786350f354bd67c8b",
            "Namely, 5e8ed b00b4",
            " ",
            "In readable hex they read ... ",
            "Sexed Booby",
            " ",
            "Aside: A Booby is a seabird in the genus Sula, part of the Sulidae family. Boobies are closely related to the gannets (Morus), which were formerly included in Sula. [source:Google] ",
            "It is important that they thrive.",
            " ",
            "But you will have plenty of choices if you don't like that one. We've found a bunch already while simultaneously heating your home.",
            " ",
            "Hash-memorable keys can be used to create applications with one less join.",
            "The key is intended to be private, but the hash can be public including the spirit animal",
            "For example the spirit animal becomes your nom de plume should you wish to participate in at www.microprediction.com",
            "   ",
            "More on that in a minute",
            "    ",
            "But first, if you do manage to generate an amusing spirit animal, by all means share it at https://www.quora.com/unanswered/What-are-the-most-amusing-hash-memorable-identifiers-you-have-generated ",
            "Or vote there on your favourite hash-memorable key",
            "We thought about calling hash-memorable keys malarkeys",
            "But that wouldn't be overly descriptive",
            "        ",
            "The most important thing about your spirit animal, let's say 'Foldable Cat' for example, is the sum of the lengths of the two words",
            "In this case the sum is 11 and this is called the length",
            "Very imaginative terminology, no?",
            "Well the length, sometimes called the difficulty is important.",
            "Maybe not as important as your liking your  'Colossal Oca', but the length determines its utilitarian value.",
            "     ",
            "Which brings us to a motivation for running this script",
            "    ",
            "Why would you want to participate at www.microprediction.com?",
            "    ",
            "Good question",
            "      ",
            "Bit of a long answer",
            "  ",
            "The short version is this: there's a microprediction web coming",
            "The microprediction web will, asymptotically, make bespoke AI cheap and ubiquitous ... though it will have humble beginnings",
            "A microprediction web will make consulting companies, artisan data scientists, and overpaid pompous managers about as relevant to model and data search as the librarian who didn't help you find this script.",
            " ",
            "We like librarians ... but there is a message in the plot here:  https://blog.oup.com/2011/06/librarian-census/    ",
            "   ",
            "Human managed data science is on the way out",
            "Collective prediction orchestrated by lightweight market-inspired mechanisms are on the way in.",
            "   ",
            "But don't take our word for it. There is a contradiction at the heart of the so-called AI revolution which you can figure out for yourself.",
            " ",
            "The contradiction runs as follows:",
            "   ",
            "   (A) The Machine Learning revolution is 'just' a bunch of problems where there is sufficient data to distinguish good from bad models by means of a simple score",
            "       Of course it is also a bunch of very clever work ... not downplaying that at all ... ",
            "          ... but ... ",
            " ",
            "   (B) It also comprises a flood of mind-numbingly daft powerpoint slides written by recent applied statisticians. ",
            "       ... who claim that their human ability to manage the production of prediction is essential",
            "       ... including managing a new type of statistics (ahem)",
            "       ... even though it mostly amounts to stating the obvious",
            "       ... and even though where there really was enough data things could be assessed by a simple score",
            "       ... which opens up the possibility for vastly more efficient ways to orchestrate production ",
            "       ... which in turn is just Econ 101",
            "       ... so long as you can reduce economic frictions of trade",
            "       ... which is exactly what we are doing here",
            "  ",
            "We say to the AI industry: what a load of malarkey! If there is enough data to distinguish good models from bad, the machines should be managing the humans and not the other way around.",
            "At least for a class of problems so defined, which we term 'microprediction' ",
            "Which is not to be confused with predicting singular events like the outcome of the 2020 US election. ",
            "   ",
            "Anyway, thankfully this script is helping in some small way",
            "By running it you are not just sitting on your hands ",
            "You are helping to stop the proliferation of expensive cold-start data science.",
            "You are taking a stand against the quaint aspirations of so-called 'number scientists'.",
            "You are helping in some small way mage progress towards affordable bespoke AI for small to medium size enterprises.",
            "You are helping in some small way to address a tragedy of the commons: the lack of a common realtime feature space.",
            "Which would have been really useful when Corono took off now, it must be admitted.",
            "That's all because hash-memorable keys carry special significance at www.microprediction.com, humble birthplace of the predictino web.",
            "The keys serve as an entry ticket, one you - or someone you kindsly donate your key to - can use in two ways.",
            "    ",
            "   (1) They enable you to enter realtime statistical prediction contests. The more difficult your key, the greater drawdown leeway you will be granted.",
            "       That's a nice way of saying that you are less likely to be kicked out because your key is declared bankrupt",
            "     ",
            "   (2) Keys enable you to ask other people and algorithms to predict live data that you care about",
            "       That can be anything at all.",
            "       But more difficult the key you supply, the more accurate the predictions will be.",
            "       That's because self-navigating automated prediction algorithms, and human guided models, are more likely to find their way to your data stream and"
            "       when they get there, will have have more incentive to fight.",
            "      ",
            "Now as a small technical matter, www.microprediction.com isn't quite operational yet.",
            "But it is close ... probably April 1, 2020 ... but don't hold me to it",
            "So we are allowing you to run this script now because it can take weeks to mine a really valuable key.",
            "And no doubt you are an under-appreciated mathematical genius ... ",
            "... or your know one who would love a really difficult key",
            " ",
            "By the way, you can run this in multiple terminals at the same time. It should only chew up 50 MB each time.",
            "We thought it would be rude to take all your processors without asking",
            "   ",
            "Oh wait I know what you are thinking ...",
            "What if I don't care about microprediction or statistics or AI or whatever and I just want to mine",
            "Will this be more economical than mining bitcoin?",
            "    ",
            "A moment's reflection might convince you that is the case, assuming ",
            "... the monetary rewards at www.microprediction.com are going to be serious",
            "... because at least one top tier investment company intends to use microprediction.com for a variety of purposes",
            "... and it is likely to be useful for many businesses",
            " ",
            "Indeed it seems plausible that some participants may be impatient",
            "... and less prescient than yourself",
            "... and thus your longer keys may be valuable to them",
            "... but we can't make any promises",
            "... though we might in the near future provide an API where you can sell keys you don't want",
            "... maybe.  ",
            " ",
            "Anyway, thanks for listenning.",
            "Next time run python3 -c 'from muid import mine; mine(skip_intro=True)' to avoid this rant",
            "Here come your keys and corresponding spirit animals. ",
            "   ",
           ]
